@@ -8,9 +8,9 @@ test_that("run_evalcurve", {
 
   res1 <- run_evalcurve(testset, toolset)
   expect_equal(is(res1), "evalcurve")
-  expect_equal(length(res1), 4)
-  expect_equal(names(res1), c("testscores", "testsum", "basepoints",
-                              "predictions"))
+  expect_equal(length(res1), 6)
+  expect_equal(names(res1), c("testscores", "testsum", "catres", "basepoints",
+                              "predictions", "titles"))
 })
 
 test_that("run_evalcurve: testset", {
@@ -41,17 +41,30 @@ test_that("run_evalcurve: toolset", {
   expect_error(run_evalcurve(testset, toolset2), "Invalid predifend tool set")
 })
 
+test_that("run_evalcurve: toolset & testset", {
+  testset <- create_testset("curve", c("c1", "c2"))
+  toolset <- create_toolset(c("ROCR", "PRROC", "PerfMeas"))
+
+  res <- run_evalcurve(testset, toolset)
+
+  expect_equal(as.character(res[[2]]$toolname),
+               rep(c("ROCR", "PRROC", "PerfMeas"), 2))
+  expect_equal(as.character(res[[2]]$testset),
+               rep(c("c1", "c2"), each = 3))
+})
+
 test_that("run_evalcurve testscores", {
   toolset <- create_toolset(set_names = "crv5")
   testset <- create_testset("curve", "c1")
   res1 <- run_evalcurve(testset, toolset)
 
   expect_equal(names(res1$testscores), c("testset", "toolset", "toolname",
-                                         "testitem", "success", "total"))
+                                         "testitem", "testcat", "success",
+                                         "total"))
   expect_true(all(res1$testscores$testset == "c1"))
   expect_true(all(res1$testscores$toolset == "crv5"))
   expect_true(any(res1$testscores$toolname == "ROCR"))
-  #expect_true(any(res1$testscores$toolname == "AUCCalculator"))
+  expect_true(any(res1$testscores$toolname == "AUCCalculator"))
   expect_true(any(res1$testscores$toolname == "PerfMeas"))
   expect_true(any(res1$testscores$toolname == "PRROC"))
   expect_true(any(res1$testscores$toolname == "precrec"))
@@ -61,12 +74,13 @@ test_that("run_evalcurve testscores", {
   res2 <- run_evalcurve(testset, toolset)
 
   expect_equal(names(res2$testscores), c("testset", "toolset", "toolname",
-                                         "testitem", "success", "total"))
+                                         "testitem", "testcat", "success",
+                                         "total"))
   expect_true(any(res2$testscores$testset == "c1"))
   expect_true(any(res2$testscores$testset == "c2"))
   expect_true(all(res2$testscores$toolset == "crv5"))
   expect_true(any(res2$testscores$toolname == "ROCR"))
-  #expect_true(any(res2$testscores$toolname == "AUCCalculator"))
+  expect_true(any(res2$testscores$toolname == "AUCCalculator"))
   expect_true(any(res2$testscores$toolname == "PerfMeas"))
   expect_true(any(res2$testscores$toolname == "PRROC"))
   expect_true(any(res2$testscores$toolname == "precrec"))
@@ -76,13 +90,14 @@ test_that("run_evalcurve testscores", {
   res3 <- run_evalcurve(testset, toolset)
 
   expect_equal(names(res3$testscores), c("testset", "toolset", "toolname",
-                                         "testitem", "success", "total"))
+                                         "testitem", "testcat", "success",
+                                         "total"))
   expect_true(any(res3$testscores$testset == "c1"))
   expect_true(any(res3$testscores$testset == "c2"))
   expect_true(any(res3$testscores$toolset == "ROCR"))
   expect_true(any(res3$testscores$toolset == "precrec"))
   expect_true(any(res3$testscores$toolname == "ROCR"))
-  #expect_true(all(res3$testscores$toolname != "AUCCalculator"))
+  expect_true(all(res3$testscores$toolname != "AUCCalculator"))
   expect_true(all(res3$testscores$toolname != "PerfMeas"))
   expect_true(all(res3$testscores$toolname != "PRROC"))
   expect_true(any(res3$testscores$toolname == "precrec"))
@@ -95,11 +110,12 @@ test_that("run_evalcurve testsum", {
 
   expect_equal(names(res1$testsum), c("testset", "toolset", "toolname",
                                       "success", "total", "label", "lbl_pos_x",
-                                      "lbl_pos_y"))
+                                      "lbl_pos_y", "label2", "lbl_pos_x2",
+                                      "lbl_pos_y2"))
   expect_true(all(res1$testsum$testset == "c1"))
   expect_true(all(res1$testsum$toolset == "crv5"))
   expect_true(any(res1$testsum$toolname == "ROCR"))
-  #expect_true(any(res1$testsum$toolname == "AUCCalculator"))
+  expect_true(any(res1$testsum$toolname == "AUCCalculator"))
   expect_true(any(res1$testsum$toolname == "PerfMeas"))
   expect_true(any(res1$testsum$toolname == "PRROC"))
   expect_true(any(res1$testsum$toolname == "precrec"))
@@ -110,12 +126,13 @@ test_that("run_evalcurve testsum", {
 
   expect_equal(names(res2$testsum), c("testset", "toolset", "toolname",
                                       "success", "total", "label", "lbl_pos_x",
-                                      "lbl_pos_y"))
+                                      "lbl_pos_y", "label2", "lbl_pos_x2",
+                                      "lbl_pos_y2"))
   expect_true(any(res2$testsum$testset == "c1"))
   expect_true(any(res2$testsum$testset == "c2"))
   expect_true(all(res2$testsum$toolset == "crv5"))
   expect_true(any(res2$testsum$toolname == "ROCR"))
-  #expect_true(any(res2$testsum$toolname == "AUCCalculator"))
+  expect_true(any(res2$testsum$toolname == "AUCCalculator"))
   expect_true(any(res2$testsum$toolname == "PerfMeas"))
   expect_true(any(res2$testsum$toolname == "PRROC"))
   expect_true(any(res2$testsum$toolname == "precrec"))
@@ -126,18 +143,75 @@ test_that("run_evalcurve testsum", {
 
   expect_equal(names(res3$testsum), c("testset", "toolset", "toolname",
                                       "success", "total", "label", "lbl_pos_x",
-                                      "lbl_pos_y"))
+                                      "lbl_pos_y", "label2", "lbl_pos_x2",
+                                      "lbl_pos_y2"))
   expect_true(any(res3$testsum$testset == "c1"))
   expect_true(any(res3$testsum$testset == "c2"))
   expect_true(any(res3$testsum$toolset == "ROCR"))
   expect_true(any(res3$testsum$toolset == "precrec"))
   expect_true(any(res3$testsum$toolname == "ROCR"))
-  #expect_true(all(res3$testsum$toolname != "AUCCalculator"))
+  expect_true(all(res3$testsum$toolname != "AUCCalculator"))
   expect_true(all(res3$testsum$toolname != "PerfMeas"))
   expect_true(all(res3$testsum$toolname != "PRROC"))
   expect_true(any(res3$testsum$toolname == "precrec"))
 })
 
+test_that("run_evalcurve catres", {
+  toolset <- create_toolset(set_names = "crv5")
+  testset <- create_testset("curve", "c1")
+  res1 <- run_evalcurve(testset, toolset)
+
+  expect_equal(names(res1$catres), c("testset", "testcat", "toolset",
+                                     "toolname", "success", "total", "label"))
+  expect_true(all(res1$catres$testset == "c1"))
+  expect_true(all(res1$catres$toolset == "crv5"))
+  expect_true(any(res1$catres$testcat == "SE"))
+  expect_true(any(res1$catres$testcat == "Ip"))
+  expect_true(any(res1$catres$testcat == "Rg"))
+  expect_true(any(res1$catres$toolname == "ROCR"))
+  expect_true(any(res1$catres$toolname == "AUCCalculator"))
+  expect_true(any(res1$catres$toolname == "PerfMeas"))
+  expect_true(any(res1$catres$toolname == "PRROC"))
+  expect_true(any(res1$catres$toolname == "precrec"))
+
+  toolset <- create_toolset(set_names = "crv5")
+  testset <- create_testset("curve", c("c1", "c2"))
+  res2 <- run_evalcurve(testset, toolset)
+
+  expect_equal(names(res2$catres), c("testset", "testcat", "toolset",
+                                    "toolname", "success", "total", "label"))
+  expect_true(any(res2$catres$testset == "c1"))
+  expect_true(any(res2$catres$testset == "c2"))
+  expect_true(all(res2$catres$toolset == "crv5"))
+  expect_true(any(res2$catres$testcat == "SE"))
+  expect_true(any(res2$catres$testcat == "Ip"))
+  expect_true(any(res2$catres$testcat == "Rg"))
+  expect_true(any(res2$catres$toolname == "ROCR"))
+  expect_true(any(res2$catres$toolname == "AUCCalculator"))
+  expect_true(any(res2$catres$toolname == "PerfMeas"))
+  expect_true(any(res2$catres$toolname == "PRROC"))
+  expect_true(any(res2$catres$toolname == "precrec"))
+
+  toolset <- create_toolset(c("ROCR", "precrec"))
+  testset <- create_testset("curve", c("c1", "c2"))
+  res3 <- run_evalcurve(testset, toolset)
+
+  expect_equal(names(res3$catres), c("testset", "testcat", "toolset",
+                                     "toolname", "success", "total", "label"))
+  expect_true(any(res3$catres$testset == "c1"))
+  expect_true(any(res3$catres$testset == "c2"))
+  expect_true(any(res3$catres$testcat == "SE"))
+  expect_true(any(res3$catres$testcat == "Ip"))
+  expect_true(any(res3$catres$testcat == "Rg"))
+  expect_true(any(res3$catres$toolset == "ROCR"))
+  expect_true(any(res3$catres$toolset == "precrec"))
+  expect_true(any(res3$catres$toolname == "ROCR"))
+  expect_true(all(res3$catres$toolname != "AUCCalculator"))
+  expect_true(all(res3$catres$toolname != "PerfMeas"))
+  expect_true(all(res3$catres$toolname != "PRROC"))
+  expect_true(any(res3$catres$toolname == "precrec"))
+})
+
 test_that("run_evalcurve basepoints", {
   toolset <- create_toolset(set_names = "crv5")
   testset <- create_testset("curve", "c1")
@@ -179,7 +253,9 @@ test_that("run_evalcurve predictions", {
   expect_true(all(res1$predictions$testset == "c1"))
   expect_true(all(res1$predictions$toolset == "crv5"))
   expect_true(any(res1$predictions$toolname == "ROCR"))
-  #expect_true(any(res1$predictions$toolname == "AUCCalculator"))
+  if (length(unique(res1$predictions$toolset)) == 5) {
+    expect_true(any(res1$predictions$toolname == "AUCCalculator"))
+  }
   expect_true(any(res1$predictions$toolname == "PerfMeas"))
   expect_true(any(res1$predictions$toolname == "PRROC"))
   expect_true(any(res1$predictions$toolname == "precrec"))
@@ -194,7 +270,9 @@ test_that("run_evalcurve predictions", {
   expect_true(any(res2$predictions$testset == "c2"))
   expect_true(all(res2$predictions$toolset == "crv5"))
   expect_true(any(res2$predictions$toolname == "ROCR"))
-  #expect_true(any(res2$predictions$toolname == "AUCCalculator"))
+  if (length(unique(res1$predictions$toolset)) == 5) {
+    expect_true(any(res2$predictions$toolname == "AUCCalculator"))
+  }
   expect_true(any(res2$predictions$toolname == "PerfMeas"))
   expect_true(any(res2$predictions$toolname == "PRROC"))
   expect_true(any(res2$predictions$toolname == "precrec"))
@@ -210,7 +288,7 @@ test_that("run_evalcurve predictions", {
   expect_true(any(res3$predictions$toolset == "ROCR"))
   expect_true(any(res3$predictions$toolset == "precrec"))
   expect_true(any(res3$predictions$toolname == "ROCR"))
-  #expect_true(all(res3$predictions$toolname != "AUCCalculator"))
+  expect_true(all(res3$predictions$toolname != "AUCCalculator"))
   expect_true(all(res3$predictions$toolname != "PerfMeas"))
   expect_true(all(res3$predictions$toolname != "PRROC"))
   expect_true(any(res3$predictions$toolname == "precrec"))
